@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
 import sys
-from . import serviceboot, build_docker
 
 
 def serviceboot_command():
@@ -11,10 +10,12 @@ def serviceboot_command():
     cmd = sys.argv[1]
 
     if cmd == 'start':
+        from . import serviceboot
         serviceboot.start()
         return
 
     if cmd == 'build_docker':
+        from . import build_docker
         build_docker.build_docker()
         return
 
